###########################################################################
#                                                                         #
# File   :	gv_filelist.tcl                                           #
# Project:	TkMount                                                   #
#                                                                         #
# Started:	22.09.97                                                  #
# Changed:	22.09.97                                                  #
# Author :      Gerhard Vogt                                              #
#                                                                         #
# Description:	This file contain the routines which allow the user       #
#               to select a directory very easily                         #
#                                                                         #
# Copyright (C) 1997 by Gerhard Vogt                                      #
#                                                                         #
# This program is free software; you can redistribute it and/or modify    #
# it under the terms of the GNU General Public License as published by    #
# the Free Software Foundation; either version 2 of the License, or       #
# (at your option) any later version.                                     #
#                                                                         #
# This program is distributed in the hope that it will be useful,         #
# but WITHOUT ANY WARRANTY; without even the implied warranty of          #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
# GNU General Public License for more details.                            #
#                                                                         #
# You should have received a copy of the GNU General Public License       #
# along with this program; if not, write to the Free Software             #
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               #
# See the file "COPYING" in the base directory of this distribution       #
# for more.                                                               #
#                                                                         #
###########################################################################

###########################################################################
# Display filelist:                                                       #
###########################################################################

proc gv_filelist {} {

global path

set w ws
set path ""
  catch {destroy .ws}
  toplevel .ws -class Dialog
  wm title .ws Mountpoint

frame .ws.right
frame .ws.left
frame .ws.top
pack .ws.top -side top
label .ws.top.path -textvar path
pack .ws.top.path -in .ws.top
pack .ws.left .ws.right -side left
listbox .ws.left.dateien -relief sunken -borderwidth 2 -yscrollcommand ".ws.left.scroll set"
pack .ws.left.dateien -side left
scrollbar .ws.left.scroll -command ".ws.left.dateien yview"
pack .ws.left.scroll -side right -in .ws.left -fill y
.ws.left.dateien insert end ".."
foreach i4 [lsort [glob -nocomplain */]] {
  .ws.left.dateien insert end $i4
  }
bind .ws.left.dateien <Button-1> {
  after 100 {
    set s [pwd]
    if {$s != "/"} {
      set path "[pwd]/[selection get]"
      regsub /$ $path {} path
    } else {
      set path "/[selection get]"
      regsub /$ $path {} path
    }    
  }}
bind .ws.left.dateien <Double-Button-1> {
 after 100 {
 catch {
    set s [pwd]
    if {$s != "/"} {
      set path "[pwd]/[selection get]"
      regsub /$ $path {} path
    } else {
      set path "/[selection get]"
      regsub /$ $path {} path
    }
    if {[file tail $path] == ".."} {
    .ws.left.dateien delete 0 end
    cd [file dirname [pwd]]
    .ws.left.dateien insert end ".."    
    foreach i4 [lsort [glob -nocomplain */]] {
      .ws.left.dateien insert end $i4
      }
    } else {
    .ws.left.dateien delete 0 end
    cd $path
    .ws.left.dateien insert end ".."    
    foreach i4 [lsort [glob -nocomplain */]] {
      .ws.left.dateien insert end $i4
      }}}
  }}
button .ws.right.ok -text OK -command {
  destroy .ws
  set mountpoint $path
  if {$mountpoint != ""} {
    .cw.left.frame$flistnr.entry3$flistnr delete 0 end
    .cw.left.frame$flistnr.entry3$flistnr insert 0 $mountpoint}  
  }
button .ws.right.cancel -text Cancel -command {
  destroy .ws
  set $path ""
  }
pack .ws.right.ok .ws.right.cancel -side top -fill x

  wm withdraw .ws
  update idletasks
  set x [expr [winfo screenwidth .ws]/2 -[winfo reqwidth .ws]/2 - [winfo vrootx [winfo parent .ws]]]
  set y [expr [winfo screenheight .ws]/2 -[winfo reqheight .ws]/2 - [winfo vrooty [winfo parent .ws]]]
  wm geom .ws +$x+$y
  wm deiconify .ws
  grab set .ws
}

###########################################################################
# Display divice-directory                                                #
###########################################################################

proc gv_devlist {} {

global path devlistnr

set w wd
set path ""
  catch {destroy .wd}
  toplevel .wd -class Dialog
  wm title .wd Devices

cd /dev
frame .wd.right
frame .wd.left
frame .wd.top
pack .wd.top -side top
label .wd.top.path -textvar path
pack .wd.top.path -in .wd.top
pack .wd.left .wd.right -side left
listbox .wd.left.dateien -relief sunken -borderwidth 2 -yscrollcommand ".wd.left.scroll set"
pack .wd.left.dateien -side left
scrollbar .wd.left.scroll -command ".wd.left.dateien yview"
pack .wd.left.scroll -side right -in .wd.left -fill y
foreach i4 [lsort [glob -nocomplain *]] {
  .wd.left.dateien insert end $i4
  }
bind .wd.left.dateien <Button-1> {
  after 100 {
    set s [pwd]
    if {$s != "/"} {
      set path "[pwd]/[selection get]"
      regsub /$ $path {} path
    } else {
      set path "/[selection get]"
      regsub /$ $path {} path
    }
  }}
button .wd.right.ok -text OK -command {
  destroy .wd
  set mountpoint $path
  if {$mountpoint != ""} {
    .cw.left.frame$devlistnr.entry2$devlistnr delete 0 end
    .cw.left.frame$devlistnr.entry2$devlistnr insert 0 $mountpoint}  
  }
button .wd.right.cancel -text Cancel -command {
  destroy .wd
  set $path ""
  }
pack .wd.right.ok .wd.right.cancel -side top -fill x

  wm withdraw .wd
  update idletasks
  set x [expr [winfo screenwidth .wd]/2 -[winfo reqwidth .wd]/2 - [winfo vrootx [winfo parent .wd]]]
  set y [expr [winfo screenheight .wd]/2 -[winfo reqheight .wd]/2 - [winfo vrooty [winfo parent .wd]]]
  wm geom .wd +$x+$y
  wm deiconify .wd
  grab set .wd
}
